capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Merge ZIP-quarter collapsed 831 files to public ZIP data
Input: 
	nearest_final_quarterly_2000 (created from office locations and GIS, located in folder ../offices/data/zip)
	fo_formerge (created from office locations and GIS, located in folder ../offices/data/zip)
	collapse_zipappall_qtr (from SAS program AEJ_PREP_831_3COLLAPSE)
*/

use "`data'\nearest_final_quarterly_2000.dta", clear;


/* ******************* */
/* **** DATA PREP **** */
/* ******************* */

keep zipcode zipcodecat statecode year quarter office1 distance1 office2 distance2 office3 distance3
	close_first post_first close_second post_second close_third post_third
	nbr1* nbr2*
	Population poverty_rate median_income male white black hispanic age* hs_drop hs_grad some_college single married
	perccommon00 perccommon00g90;

rename zipcode zip;
rename zipcodecat zipcat;
rename Population c_pop;
rename poverty_rate c_povrate;
rename median_income c_medinc;
rename male c_male;
rename white c_racew;
rename black c_raceb;
rename hispanic c_raceh;
rename age0to19 c_age0to19;
rename age20to44 c_age20to44;
rename age45to64 c_age45to64;
rename hs_drop c_edhsdrop;
rename hs_grad c_edhsgrad;
rename some_college c_edsomec;
rename single c_maritalnever;
rename married c_maritalmar;

/* Missing categories */
replace c_povrate=c_povrate/100;
gen c_female=1-c_male;
gen c_raceo=1-c_racew-c_raceb-c_raceh;
gen c_age65plus=1-c_age0to19-c_age20to44-c_age45to64;
gen c_edcoll=1-c_edhsdrop-c_edhsgrad-c_edsomec;
gen c_maritalprev=1-c_maritalnever-c_maritalmar;

order 
zip zip statecode year quarter office1 distance1 office2 distance2 office3 distance3
close_first post_first close_second post_second close_third post_third
nbr1* nbr2*
c_pop c_povrate c_medinc c_male c_female c_racew c_raceb c_raceh c_raceo c_age0to19 c_age20to44 c_age45to64 c_age65plus
c_edhsdrop c_edhsgrad c_edsomec c_edcoll c_maritalnever c_maritalmar c_maritalprev;

/* Population of the service area of the FO closest to ZIP */
gen qtryear=yq(year, quarter);
preserve;
collapse (sum) c_pop, by(office1 qtryear);
rename c_pop c_fopop;
reshape wide c_fopop, i(office1) j(qtryear);
foreach var of varlist c_* {;
	replace `var'=0 if `var'==.;
};
reshape long c_fopop, i(office1) j(qtryear);
tempfile officepop ;
save `officepop' ;
restore;
merge m:1 office1 qtryear using `officepop', keepusing(c_fopop);
drop if _merge==2;
drop _merge;

/* Applicant population of the service area of the FO closest to ZIP, processing time (4-quarter running average to avoid seasonality) */
merge m:1 zip year quarter using "`data'\collapse_zipappall_qtr.dta", keepusing(all_a_ctnum all_sumdaysproc all_numprocgt40);
drop if _merge == 2 ;
drop _merge ;
sort zip qtryear ;

/* Apps/proctime 2 quarters prior */
gen all_a_ctnum_minus2 = all_a_ctnum[_n-2] ;
gen all_sumdaysproc_minus2  = all_sumdaysproc[_n-2] ;
gen all_numprocgt40_minus2  = all_numprocgt40[_n-2] ;

/* Collapse by office and quarter */
preserve;
collapse (sum) all_a_ctnum all_a_ctnum_minus2 all_sumdaysproc all_sumdaysproc_minus2 all_numprocgt40 all_numprocgt40_minus2
	, by(office1 qtryear) ;

gen foproc_qtr = all_sumdaysproc / all_a_ctnum if all_a_ctnum > 5 ; 
gen foproc_qtr2min = all_sumdaysproc_minus2 / all_a_ctnum_minus2 if all_a_ctnum_minus2 > 5 ;
gen numprocgt40_qtr = all_numprocgt40 / all_a_ctnum if all_a_ctnum > 5 ; 
gen numprocgt40_qtr2min = all_numprocgt40_minus2 / all_a_ctnum_minus2 if all_a_ctnum_minus2 > 5 ;
rename all_a_ctnum foapp_qtr ;
rename all_a_ctnum foapp_qtr2min ;
summ fo* ;

/* Replace msisings with zero */
drop all_sumdays* all_numproc* ;
reshape wide foapp_qtr foapp_qtr2min foproc_qtr foproc_qtr2min numprocgt40_qtr numprocgt40_qtr2min, i(office1) j(qtryear) ;
foreach var of varlist foapp_* foproc_* numprocgt40_* {;
	replace `var'=0 if `var'==.;
};
reshape long foapp_qtr foapp_qtr2min foproc_qtr foproc_qtr2min numprocgt40_qtr numprocgt40_qtr2min, i(office1) j(qtryear);	
sort office1 qtryear ;

/* Create average over past 4 quarters to avoid seasonality */
foreach stub in foapp foproc numprocgt40 { ;
	gen `stub'_4qtr 	= (`stub'_qtr[_n] + `stub'_qtr[_n-1] + `stub'_qtr[_n-2] + `stub'_qtr[_n-3]) / 4 ;						
	gen `stub'_4qtr2min = (`stub'_qtr2min[_n] + `stub'_qtr2min[_n-1] + `stub'_qtr2min[_n-2] + `stub'_qtr2min[_n-3]) / 4 ; 	
} ;
summ foapp_qtr foapp_4qtr foproc_qtr foproc_4qtr numprocgt40_qtr numprocgt40_4qtr ; 
summ foapp_qtr2min foapp_4qtr2min foproc_qtr2min foproc_4qtr2min numprocgt40_qtr2min numprocgt40_4qtr2min ;

/* Create office2 variables to merge in later */
gen office2 = office1 ;
gen foproc_4qtr2 = foproc_4qtr ;
gen numprocgt40_4qtr2 = numprocgt40_4qtr ;
tempfile officeapp ;
save `officeapp' ;
restore;

merge m:1 office1 qtryear using `officeapp', 
	keepusing(	foapp_qtr foapp_4qtr foapp_qtr2min foapp_4qtr2min 
				foproc_qtr foproc_4qtr foproc_qtr2min 
				numprocgt40_qtr numprocgt40_4qtr numprocgt40_qtr2min numprocgt40_4qtr2min
				);
drop if _merge==2; 
drop _merge;
drop qtryear;


/* **************************** */
/* **** CLASSIFY ZIP CODES **** */
/* **************************** */

preserve;

keep zip office1 nbr1no_first nbr1no_second nbr1no_third;
foreach type in office1 nbr1no_first nbr1no_second nbr1no_third {;
	merge m:1 `type' using "`data'\fo_formerge.dta", keepusing(`type'_cls);
	keep if _merge==1 | _merge==3;
	drop _merge;
	replace `type'_cls=0 if `type'==.;
};

/* Collapse by ZIP */
collapse (max) office1_cls nbr1no_first_cls nbr1no_second_cls nbr1no_third_cls, by(zip);
tempfile collapse ;
save `collapse' ;

restore;
merge m:1 zip using `collapse' ;
drop _merge;

foreach var in office1_cls nbr1no_first_cls nbr1no_second_cls nbr1no_third_cls {;
	tab `var';
};

save "`data'\zip_for831merge_qtr.dta", replace;
