capture log close
clear all
set maxvar 32767
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Run regressions for Table 5
Input: 
	nearest_final_qtr_officeapp_formerge (created from SSA data, located in folder ../offices/data/zip)
	fostaff_formerge_qtr (from AEJ_PREP_STAFF)
	populationdensity (created from public-use data, located in folder ../offices/data/zip)
	zip_for831_eventstudy_clsnbriv_forreg (from AEJ_831_ESTUDY_PREP3)
*/

local pre "12";
local post "8";
scalar define scpre=12;
scalar define scpost=8;

/* ************************************ */
/* **** PREP INSTRUMENT DATA FILES **** */
/* ************************************ */

/* Prepare service area application for merge */
use "`data'\nearest_final_qtr_officeapp_formerge.dta", clear;

drop office2 foproc_4qtr2 ;
gen newoffice = office1 ;
gen oldoffice = office1 ;
gen csetqtr_post = qtryear ;
gen csetqtr_pre = qtryear ;
tempfile officeapp;
save `officeapp';

/* Prepare staff data for merge */
use "`staff'\fostaff_formerge_qtr.dta", clear ;

gen newoffice = office1 ;
gen oldoffice = office1 ;
gen csetyr_post = year ;
gen csetyr_pre = year ;
tempfile officestaff;
save `officestaff';


/* ****************************************************************** */
/* **** INSTRUMENT 1: DIFFERENCE IN BASELINE CONGESTION/DISTANCE **** */
/* ****************************************************************** */
 
use "`data'\zip_for831_eventstudy_clsnbriv_forreg.dta", clear;

tab cls, m ;
tab nbr, m ;

gen byte post=(eqtryear>0) ;
gen byte qtrzero=(eqtryear==0) ;

/* Create rural variable */
rename zip zipcode ;
merge m:1 zipcode using "`data'\populationdensity.dta" ;
drop if _merge==2 ;
drop _merge ;
rename zipcode zip ;
summ density, det ;
gen byte rural = (density < 25) ;
tab rural, m ;
gen postXrural = post * rural ;

/* Instrument 1: driving diff and congestion diff */
gen postXddiff = post * office2_distdiff ;
gen postXprocdiff = post * office2_procdiff ;

summ foproc_4qtr dist_driving1 post postXprocdiff postXddiff ;
summ foproc_4qtr dist_driving1 post postXprocdiff postXddiff if cls == 1 ;
summ foproc_4qtr dist_driving1 post postXprocdiff postXddiff if nbr == 1 ;

count;

foreach var of varlist postXprocdiff postXddiff foproc_4qtr dist_driving1 {;
	count if all_a_ctnum == . ;
};


/* ******************************************************************** */
/* **** INSTRUMENT 2: CHANGE IN DEMAND (SERVICE AREA APPLICATIONS) **** */
/* ******************************************************************** */

/* Merge in service apps for newoffice from quarter before closing */
merge m:1 newoffice csetqtr_pre using `officeapp', keepusing(foapp_4qtr);
keep if _merge != 2 ;
drop _merge ;
rename foapp_4qtr foapp_csetpre ;

/* Merge in service apps for my newoffice FOR ALL ZIPS IN NEW SERVICE AREA but from quarter before closing, this year */
merge m:1 newoffice csetqtr_post using `officeapp', keepusing(foapp_4qtr2min);
keep if _merge != 2 ;
drop _merge ;
rename foapp_4qtr2min foapp_csetpost ;

count if foapp_csetpre != . & foapp_csetpost != . ;
count if foapp_csetpre <= foapp_csetpost & foapp_csetpre != . & foapp_csetpost != . ;

/* Percent change in service area pop */
gen foapp_diff = foapp_csetpost - foapp_csetpre ;
gen foapp_pct = (foapp_csetpost - foapp_csetpre) / foapp_csetpre if foapp_csetpre != 0 ;
count if foapp_pct == . ;
summ foapp_pct ;

/* Create instrument */
gen     postXfoapp_lvl = foapp_diff * post if cls == 1 ;
replace postXfoapp_lvl = foapp_diff * post if nbr == 1 ;


/* *************************************************** */
/* **** INSTRUMENT 3: CHANGE IN SUPPLY (FO STAFF) **** */
/* *************************************************** */
 
/* Merge in staff for newoffice, last year */
merge m:1 newoffice csetyr_pre using `officestaff', keepusing(staff);
keep if _merge != 2 ;
drop _merge ;
rename staff staff_csetpre ;

/* Merge in staff for newoffice, this year */
merge m:1 newoffice csetyr_post using `officestaff', keepusing(staff);
keep if _merge != 2 ;
drop _merge ;
rename staff staff_csetpost ;

count if staff_csetpost != . & staff_csetpre != . ;
count if staff_csetpre <= staff_csetpost & staff_csetpost != . & staff_csetpre != . ;

/* Percent change in service area pop */
gen staff_diff = staff_csetpost - staff_csetpre ;
gen staff_pct = (staff_csetpost - staff_csetpre) / staff_csetpre if staff_csetpre != 0 ;
count if staff_pct == . ;
summ staff_pct ;

/* Create instrument */
gen     postXstaff_lvl = staff_diff * post if cls == 1 ;
replace postXstaff_lvl = staff_diff * post if nbr == 1 ;


/* ****************************** */
/* **** PREP FOR REGRESSIONS **** */
/* ****************************** */

/* Create weights */
foreach stub in all {;
	foreach type in a r {;
		gen temp_`type'_`stub'=`stub'_`type'_ctnum if eqtryear<0 & eqtryear>=-4;
		egen weight_`type'_`stub'=mean(temp_`type'_`stub'), by(cset zip);
		drop temp_*;
	};
};

/* Convert to log applications variable */
foreach type in a r { ;
	gen all_`type'_lvlnum=all_`type'_ctnum;
	summ all_`type'_ctnum;
	replace all_`type'_ctnum = 1 if all_`type'_ctnum <= 0 ;
	replace all_`type'_ctnum = log(all_`type'_ctnum) ;
	summ all_`type'_ctnum ;
} ;

/* StateXyear fixed effects */
keep if eqtryear>=-`pre' & eqtryear<=`post';
drop if year==2015 & (quarter==3 | quarter==4);
tab statecode, m;
tab year, m;
egen stateXyear=group(statecode year);
tab stateXyear, m;
gen unique=_n;
egen temp=count(unique), by(stateXyear);
tab temp, m;
summ temp;
pctile pct=temp, n(100);
local p90=pct[90];
replace stateXyear=9999 if temp<`p90' ;
tab stateXyear, m;
drop pct temp;

/* Get weighted rural average for calculations */
summ rural postXrural [aw=weight_a_all] ;
summ rural postXrural [aw=weight_r_all] ;


/* ************************ */
/* **** IV REGRESSIONS **** */
/* ************************ */
drop csetdate office* from_* time* dist_driving2 ;
sort zip eqtryear qtryear;
duplicates drop zip eqtryear, force;
tsset zip eqtryear;	

summ eqtryear;
local min = r(min);
gen t = eqtryear - `min' ;
tab t, m;

rename foproc_4qtr endo_proc  ;
summ endo_proc, det ;
gen clsnbr = 1;

xi: areg all_a_ctnum
			 endo_proc dist_driving1
			 postXprocdiff postXfoapp_lvl postXstaff_lvl
			 postXddiff
			 post postXrural qtrzero t
			 i.stateXyear i.quarter 
			 if sample_all==1 & clsnbr==1
			 [aweight=weight_a_all]
	 , absorb(zip) vce(cluster cset);
	outreg2 using "`output'\table5.xls", replace;

/* Reduced form and first stage for congestion */
foreach lhs in all_a_ctnum endo_proc {;
	 xi: areg `lhs' 
					 postXddiff postXprocdiff postXfoapp_lvl postXstaff_lvl
					 post postXrural qtrzero t
					 i.stateXyear i.quarter 
					 if sample_all==1 & clsnbr==1
					 [aweight=weight_a_all]
			 , absorb(zip) vce(cluster cset);
	 outreg2 using "`output'\table5.xls", append;
	 test postXddiff postXprocdiff postXfoapp_lvl postXstaff_lvl;
	};

/* Individual first stage relationships */
foreach rhs in postXprocdiff postXfoapp_lvl postXstaff_lvl {;
	 xi: areg endo_proc 
					 `rhs'
					 post postXrural qtrzero t
					 i.stateXyear i.quarter 
					 if sample_all==1 & clsnbr==1
					 [aweight=weight_a_all]
			 , absorb(zip) vce(cluster cset);
	 outreg2 using "`output'\table5.xls", append;
	};

/* Reduced form and first stage for distance */
foreach lhs in all_a_ctnum dist_driving1 {;
		 xi: areg `lhs' 
						 postXddiff postXddiff postXprocdiff postXfoapp_lvl postXstaff_lvl
						 post postXrural qtrzero t
						 i.stateXyear i.quarter  
						 if sample_all==1 & clsnbr==1
						 [aweight=weight_a_all]
				 , absorb(zip) vce(cluster cset);
		 outreg2 using "`output'\table5.xls", append;
		 test postXddiff postXprocdiff postXfoapp_lvl postXstaff_lvl;
 };

/* Multiple instrument reduced form */
xi: areg all_a_ctnum 
			 postXddiff 
			 postXprocdiff postXfoapp_lvl postXstaff_lvl
			 post postXrural qtrzero t
			 i.stateXyear i.quarter 
			 if sample_all==1 & clsnbr==1
			 [aweight=weight_a_all]
	 , absorb(zip) vce(cluster cset);
outreg2 using "`output'\table5.xls", append;

/* Simple reduced form */
foreach lhs in all_a_ctnum endo_proc dist_driving1 { ;
		 xi: areg `lhs' 
						 post postXrural qtrzero t
						 i.stateXyear i.quarter 
						 if sample_all==1 & clsnbr==1
						 [aweight=weight_a_all]
				 , absorb(zip) vce(cluster cset);
		 outreg2 using "`output'\table5.xls", append;
 };

/* OLS */
xi: areg all_a_ctnum 
			 endo_proc dist_driving1 
			 post postXrural qtrzero t
			 i.stateXyear i.quarter 
			 if sample_all==1 & clsnbr==1
			 [aweight=weight_a_all]
	 , absorb(zip) vce(cluster cset);
outreg2 using "`output'\table5.xls", append;

/* IV */
xi: xtivreg2 all_a_ctnum 
		 (endo_proc dist_driving1 = postXprocdiff postXfoapp_lvl postXstaff_lvl postXddiff)
		 post postXrural qtrzero t
		 i.stateXyear i.quarter 
		 if sample_all==1 & clsnbr==1
		 [aweight=weight_a_all]
		 , fe robust cluster(cset);
outreg2 using "`output'\table5.xls", append;

